[PATCH] D145786: [LLD] Increase thunk pass limit

Peter Smith via Phabricator via llvm-commits llvm-commits at lists.llvm.org
Mon Mar 13 03:06:32 PDT 2023


This revision was automatically updated to reflect the committed changes.
Closed by commit rG7ef47dd54e2d: [LLD] Increase thunk pass limit (authored by psmith).
Herald added a project: LLVM.

Repository:
  rG LLVM Github Monorepo

CHANGES SINCE LAST ACTION
  https://reviews.llvm.org/D145786/new/

https://reviews.llvm.org/D145786

Files:
  lld/ELF/Writer.cpp


Index: lld/ELF/Writer.cpp
===================================================================
--- lld/ELF/Writer.cpp
+++ lld/ELF/Writer.cpp
@@ -1647,8 +1647,8 @@
     ++pass;
 
     // With Thunk Size much smaller than branch range we expect to
-    // converge quickly; if we get to 15 something has gone wrong.
-    if (changed && pass >= 15) {
+    // converge quickly; if we get to 30 something has gone wrong.
+    if (changed && pass >= 30) {
       error(target->needsThunks ? "thunk creation not converged"
                                 : "relaxation not converged");
       break;


-------------- next part --------------
A non-text attachment was scrubbed...
Name: D145786.504571.patch
Type: text/x-patch
Size: 593 bytes
Desc: not available
URL: <http://lists.llvm.org/pipermail/llvm-commits/attachments/20230313/43a44b8e/attachment.bin>


More information about the llvm-commits mailing list